/*
Copyright 2017-2022 CAcert Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package handlers

import (
	"context"
	"encoding/gob"

	"github.com/alexedwards/scs/v2"
)

type FlashVariant string

const (
	flashWarning FlashVariant = "warning"
	flashInfo    FlashVariant = "info"
	flashSuccess FlashVariant = "success"
)

type FlashMessage struct {
	Variant FlashVariant
	Title   string
	Message string
}

type FlashHandler struct {
	sessionManager *scs.SessionManager
}

func NewFlashes(manager *scs.SessionManager) *FlashHandler {
	gob.Register([]FlashMessage{})

	return &FlashHandler{sessionManager: manager}
}

func (f *FlashHandler) addFlash(ctx context.Context, message *FlashMessage) {
	flashes := f.flashes(ctx)

	flashes = append(flashes, *message)

	f.sessionManager.Put(ctx, "flashes", flashes)
}

func (f *FlashHandler) flashes(ctx context.Context) []FlashMessage {
	flashInstance := f.sessionManager.Pop(ctx, "flashes")

	if flashInstance != nil {
		flashes, ok := flashInstance.([]FlashMessage)

		if ok {
			return flashes
		}
	}

	return make([]FlashMessage, 0)
}
