/*
Copyright 2022 CAcert Inc.
SPDX-License-Identifier: Apache-2.0

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Package models defines data models and database access types.
package models

import (
	"fmt"
	"time"
)

func parseSqlite3TimeStamp(timeStamp string) (*time.Time, error) {
	const (
		sqlite3TsStringFormat      = "2006-01-02 15:04:05.999999999-07:00"
		sqlite3ShortTsStringFormat = "2006-01-02 15:04:05"
	)

	var (
		result time.Time
		err    error
	)

	if result, err = time.Parse(sqlite3TsStringFormat, timeStamp); err == nil {
		result = result.UTC()

		return &result, nil
	}

	if result, err = time.ParseInLocation(sqlite3ShortTsStringFormat, timeStamp, time.UTC); err == nil {
		result = result.UTC()

		return &result, nil
	}

	return nil, fmt.Errorf("could not parse timestamp: %w", err)
}

func errCouldNotExecuteQuery(err error) error {
	return fmt.Errorf("could not execute query: %w", err)
}
func errCouldNotFetchRow(err error) error {
	return fmt.Errorf("could not fetch row: %w", err)
}
func errCouldNotScanResult(err error) error {
	return fmt.Errorf("could not scan result: %w", err)
}
func errCouldNotStartTransaction(err error) error {
	return fmt.Errorf("could not start transaction: %w", err)
}
func errCouldNotCommitTransaction(err error) error {
	return fmt.Errorf("could not commit transaction: %w", err)
}
func errCouldNotCreateInQuery(err error) error {
	return fmt.Errorf("could not create query with IN clause: %w", err)
}
